#!/usr/bin/env bash

working_dir="$(dirname $(realpath $0))"
conf_file="${working_dir}/conf/mysql_credetials.conf"

#LOGGING=true
LOGGING=false


# -------------
# --- Some functions
# -------------

fatal(){
   echo ""
   if $terminal ; then
      if [[ -n "$*" ]] ; then
         echo -e "   [ \033[31m\033[1mFatal\033[m ]: $*"
         echo ""
         echo -e "              \033[31m\033[1mScript will be interrupted.\033[m\033[m"
      else
         echo -e "   \033[31m\033[1mFatal error\033[m: \033[1mScript will be interrupted.\033[m"
      fi
   else
      if [[ -n "$*" ]] ; then
         echo "   [ Fatal ]: $*"
         echo ""
         echo "              Script was terminated.."
      else
         echo "   Fatal error: Script was terminated.."
      fi
   fi
   echo ""
   clean_up 1
}

detect_mysql_version () {

   _MYSQLD_VERSION="$(mysqld -V 2>/dev/null)"

   if [[ -z "$_MYSQLD_VERSION" ]]; then
      fatal "No installed MySQL server or distribution found!"
   elif [[ "$_MYSQLD_VERSION" =~ MariaDB ]]; then
      MYSQL_CUR_DISTRIBUTION="MariaDB"
   elif [[ "$(basename "$(realpath "/usr/local/mysql")")" =~ percona- ]]; then
      MYSQL_CUR_DISTRIBUTION="Percona"
   elif [[ "$(basename "$(realpath "/usr/local/mysql")")" =~ mysql- ]]; then
      MYSQL_CUR_DISTRIBUTION="MySQL"
   fi

   MYSQL_VERSION="$(echo $_MYSQLD_VERSION | grep -o -E "[0-9]+\.[0-9]+\.[0-9]+(-[0-9]+)?" | head -n 1)"
   MYSQL_MAJOR_VERSION="$(echo $MYSQL_VERSION | cut -d '.' -f1)"
   MYSQL_MINOR_VERSION="$(echo $MYSQL_VERSION | cut -d '.' -f2)"
   MYSQL_PATCH_LEVEL="$(echo $MYSQL_VERSION | cut -d '.' -f3)"
   MYSQL_MAIN_VERSION="$(echo $MYSQL_VERSION | cut -d '.' -f1,2)"

}



mysqladmin=`realpath $(which mysqladmin) 2>/dev/null`
if [ -z "$mysqladmin" ]; then
   if [ -x "/usr/local/mysql/bin/mysqladmin" ]; then
      mysql=/usr/local/mysql/bin/mysqladmin
   else
      echo
      echo -e "\t[ Error ]: \"mysqladmin\"  not found !!!"
      echo
      exit
   fi
fi


# - Is this script running on terminal ?
# -
if [[ -t 1 ]] ; then
   terminal=true
else
   terminal=false
fi



#---------------------------------------
#-----------------------------
# Read Configurations from $conf_file
#-----------------------------
#---------------------------------------

if [[ -f "$conf_file" ]]; then
   source "$conf_file"
fi

#[[ -z "$mysql_credential_args" ]] && mysql_credential_args="--defaults-file=/usr/local/mysql/sys-maint.cnf"


if $LOGGING ;then
   echo -e "\n[ `date` ] Going to flush host cache.."
fi

if [[ -z "$mysql_credential_args" ]]; then
	
   detect_mysql_version

   MAJOR_VERSION="$MYSQL_MAJOR_VERSION"
   MINOR_VERSION="$MYSQL_MINOR_VERSION"
   PATCH_LEVEL="$MYSQL_PATCH_LEVEL"

   if [[ "$MYSQL_CUR_DISTRIBUTION" = "MariaDB" ]] && ([[ $MAJOR_VERSION -gt 10 ]] \
         || ( [[ $MAJOR_VERSION -eq 10 ]] && [[ $MINOR_VERSION -gt 3 ]] )) ; then
      if [[ -S "/tmp/mysql.sock" ]]; then
         mysql_credential_args="-u root -S /tmp/mysql.sock"
      elif [[ -S "/run/mysqld/mysqld.sock" ]]; then
         mysql_credential_args="-u root -S /run/mysqld/mysqld.sock"
      elif [[ -S "/var/run/mysqld/mysqld.sock" ]]; then
         mysql_credential_args="-u root -S /var/run/mysqld/mysqld.sock"
      else
         fatal "Parameter 'MYSQL_CREDENTIAL_ARGS' cannot be determined automated. 

              Use configuration file "$conf_file" to set 
              parameter manually."
      fi
   else
      if [[ -f "/usr/local/mysql/sys-maint.cnf" ]] ; then
         mysql_credential_args="--defaults-file=/usr/local/mysql/sys-maint.cnf"
      elif [[ -f "/etc/mysql/debian.cnf" ]] ; then
         mysql_credential_args="--defaults-file=/etc/mysql/debian.cnf"
      else
         fatal "Parameter 'MYSQL_CREDENTIAL_ARGS' cannot be determined automated. 

              Use configuration file "$conf_file" to set 
              parameter manually."
      fi
   fi
fi


# Flush host cache
#
$mysqladmin $mysql_credential_args flush-hosts

[[ $? -gt 0 ]] && echo -e "\t[ Error ]: Flushing host cache failed !!"

if $LOGGING ;then
    echo -e "\n[ `date` ] End flushing host cache"
fi

exit 0
